pub struct LtcDecoder { /* private fields */ }Expand description
Minimal LTC frame-boundary detector.
In a real system LTC is an 80-bit bi-phase mark coded audio signal.
This implementation models the state machine that detects a sync word
and returns the number of complete frames found in an audio sample
buffer (where each bit is represented as a single bool sample for
simplicity / testability).
Implementations
Sourceimpl LtcDecoder
impl LtcDecoder