TimecodeScheduler

Struct TimecodeScheduler 

pub struct TimecodeScheduler { /* private fields */ }
Frame-accurate timecode playback scheduler.

Maintains an internal frame counter and fires registered triggers when playback passes their target timecode.

Implementations

Source

impl TimecodeScheduler

pub fn new(rate: FrameRate, drop_frame: bool) -> Self

Create a new scheduler, starting at 00:00:00:00.

pub fn current_timecode(&self) -> Option<Timecode>

Current timecode.

Returns None only if the frame count is somehow invalid.

pub fn seek(&mut self, tc: Timecode)

Seek to a specific timecode.

pub fn advance_frames(&mut self, frames: u64) -> FiredTriggers

Advance by frames frames and return any fired triggers.

pub fn register_trigger( &mut self, target: Timecode, label: impl Into<String>, one_shot: bool, ) -> TriggerId

Register a trigger at a target timecode.

Returns the TriggerId assigned.

pub fn unregister_trigger(&mut self, id: TriggerId)

Remove a trigger.

pub fn trigger_label(&self, id: TriggerId) -> Option<&str>

Get the label of a trigger.

pub fn trigger_count(&self) -> usize

Number of registered triggers.

pub fn reset(&mut self)

Reset to 00:00:00:00.